@@ -53,6 +53,7 @@ class RebuilddConfig(object, ConfigParser.ConfigParser):
         self.set('build', 'database_uri', 'sqlite:///var/lib/rebuildd/rebuildd.db')
         self.set('build', 'build_more_recent', '1')
         self.set('build', 'more_archs', 'any')
+        self.set('build', 'no_system_arch', '0')
 
         self.set('mail', 'from', 'rebuildd@localhost')
         self.set('mail', 'mailto', 'rebuildd@localhost')
@@ -74,19 +75,20 @@ class RebuilddConfig(object, ConfigParser.ConfigParser):
         self.set('http', 'logfile', '/var/log/rebuildd/httpd.log')
 
         self.set('log', 'file', "/var/log/rebuildd/rebuildd.log")
-        self.set('log', 'time_format', "%d-%m-%Y %H:%M:%S")
+        self.set('log', 'time_format', "%Y-%m-%d %H:%M:%S")
         self.set('log', 'logs_dir', "/var/log/rebuildd/build_logs")
         self.set('log', 'mail_failed', '1')
         self.set('log', 'mail_successful', '0')
 
-        self.arch = []
-        parch = os.popen("dpkg --print-architecture")
-        self.arch.append(parch.readline().strip())
-        parch.close()
-
         if not dontparse:
             self.reload()
 
+        self.arch = []
+        if self.getint('build', 'no_system_arch') == 0:
+            parch = os.popen("dpkg --print-architecture")
+            self.arch.append(parch.readline().strip())
+            parch.close()
+
         for a in self.get('build', 'more_archs').split(' '):
             self.arch.append(a)
 
