@@ -2,6 +2,7 @@ from rebuildd.RebuilddConfig import RebuilddConfig
 from rebuildd.Rebuildd import Rebuildd
 from rebuildd.Package import Package
 from rebuildd.Job import Job
+from rebuildd.RebuilddLog import Log
 import os
 
 def rebuildd_global_test_setup():
@@ -14,13 +15,22 @@ def rebuildd_global_test_setup():
         RebuilddConfig().set('build', 'build_more_recent', '0') 
         RebuilddConfig().set('log', 'mail_successful', '0')
         RebuilddConfig().arch = ["alpha", "any"]
-        try:
-            os.unlink("/tmp/rebuildd-tests.db")
-        except OSError:
-            pass
         Rebuildd()
         try:
+            Package.dropTable(ifExists=True)
+            Job.dropTable(ifExists=True)
+            Log.dropTable(ifExists=True)
             Package.createTable()
             Job.createTable()
+            Log.createTable()
         except:
-             pass
+            pass
+
+def rebuildd_global_test_teardown():
+        try:
+            Rebuildd()._sqlconnection.dropDatabase()
+            Rebuildd()._sqlconnection.close()
+	    Rebuildd()._sqlconnection._threadPool = {}
+        except:
+            pass
+                
